How-to Guides
=============

.. toctree::
   :maxdepth: 1

   how-to-guides/custom-generation-strategies.rst
   how-to-guides/attach-data-to-experiments.rst
   how-to-guides/acquire-baseline.rst
   how-to-guides/set-dof-constraints.rst
